webbpsf\_ext.image\_manip
=========================

.. automodule:: webbpsf_ext.image_manip

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree:
   
      add_ipc
      add_ppc
      apply_pixel_diffusion
      bp_fix
      convolve_image
      crop_image
      crop_observation
      crop_zero_rows_cols
      cv_shift
      distort_image
      expand_mask
      fourier_imshift
      fractional_image_shift
      frebin
      fshift
      get_im_cen
      image_convolution
      image_rescale
      image_shift_with_nans
      make_disk_image
      model_to_hdulist
      pad_or_cut_to_size
      replace_nans
      replace_nans_griddata
      rotate_offset
      rotate_shift_image
      zrebin
   
   

   
   
   

   
   
   



